==> kdeedu_4.4.5.orig.tar.bz2: kdeedu-4.4.5/marble/src/lib/geodata/handlers/osm-namefinder/AttributeDictionary.h <==
/*
    Copyright (C) 2008 Jens-Michael Hoffmann <jensmh@gmx.de>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef OsmNamefinder_AttributeDictionary_h
#define OsmNamefinder_AttributeDictionary_h

#include <marble_export.h>

namespace Marble
{
namespace OsmNamefinder
{

extern const char *attr_approxdistance;
extern const char *attr_category;
extern const char *attr_date;
extern const char *attr_direction;
extern const char *attr_distance;
extern const char *attr_distancesearch;
extern const char *attr_find;
extern const char *attr_findisin;
extern const char *attr_findname;
extern const char *attr_findplace;
extern const char *attr_foundnearplace;
extern const char *attr_from;
extern const char *attr_fromtype;
extern const char *attr_id;
extern const char *attr_info;
extern const char *attr_is_in;
extern const char *attr_lat;
extern const char *attr_lon;
extern const char *attr_name;
extern const char *attr_rank;
extern const char *attr_region;
extern const char *attr_sourcedate;
extern const char *attr_to;
extern const char *attr_totype;
extern const char *attr_type;
extern const char *attr_zoom;

}
}

#endif

==> kdeedu-4.5.1.tar.bz2: kdeedu-4.5.1/marble/src/lib/geodata/handlers/osm-namefinder/AttributeDictionary.h <==
/*
    Copyright (C) 2008 Jens-Michael Hoffmann <jensmh@gmx.de>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef MARBLE_ONF_ATTRIBUTEDICTIONARY_H
#define MARBLE_ONF_ATTRIBUTEDICTIONARY_H

#include <marble_export.h>

namespace Marble
{
namespace OsmNamefinder
{

extern const char *attr_approxdistance;
extern const char *attr_category;
extern const char *attr_date;
extern const char *attr_direction;
extern const char *attr_distance;
extern const char *attr_distancesearch;
extern const char *attr_find;
extern const char *attr_findisin;
extern const char *attr_findname;
extern const char *attr_findplace;
extern const char *attr_foundnearplace;
extern const char *attr_from;
extern const char *attr_fromtype;
extern const char *attr_id;
extern const char *attr_info;
extern const char *attr_is_in;
extern const char *attr_lat;
extern const char *attr_lon;
extern const char *attr_name;
extern const char *attr_rank;
extern const char *attr_region;
extern const char *attr_sourcedate;
extern const char *attr_to;
extern const char *attr_totype;
extern const char *attr_type;
extern const char *attr_zoom;

}
}

#endif
